@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 __PACKAGE__->add_method_maker_argument_names
 (
@@ -26,6 +26,9 @@ sub type { 'array' }
 sub method_maker_class { 'Rose::DB::Object::MakeMethods::Generic' }
 sub method_maker_type  { 'array' }
 
+sub parse_value  { shift; shift->parse_array(@_)  }
+sub format_value { shift; shift->format_array(@_) }
+
 1;
 
 __END__
@@ -68,6 +71,10 @@ Returns C<Rose::DB::Object::MakeMethods::Generic>.
 
 Returns C<array>.
 
+=item B<parse_value DB, VALUE>
+
+Parse VALUE and return a reference to an array containing the array values.  DB is a C<Rose::DB> object that is  used as part of the parsing process.  Both arguments are required.
+
 =item B<type>
 
 Returns "array".
